@@ -21,7 +21,7 @@ module Ethon
         base.attach_function :easy_setopt_off_t,          :curl_easy_setopt,         [:pointer, :easy_option, :int64],    :easy_code
         base.instance_variable_set(:@blocking, true)
         base.attach_function :easy_perform,               :curl_easy_perform,        [:pointer],                     :easy_code
-        base.attach_function :easy_strerror,              :curl_easy_strerror,       [:int],                         :string
+        base.attach_function :easy_strerror,              :curl_easy_strerror,       [:easy_code],                   :string
         base.attach_function :easy_escape,                :curl_easy_escape,         [:pointer, :pointer, :int],     :pointer
         base.attach_function :easy_reset,                 :curl_easy_reset,          [:pointer],                     :void
 
@@ -44,6 +44,8 @@ module Ethon
         base.attach_function :multi_setopt_off_t,         :curl_multi_setopt,        [:pointer, :multi_option, :int64],    :multi_code
 
         base.attach_function :version,                    :curl_version,             [],                             :string
+        base.attach_function :version_info,               :curl_version_info,        [],                             Curl::VersionInfoData.ptr
+
         base.attach_function :slist_append,               :curl_slist_append,        [:pointer, :string],            :pointer
         base.attach_function :slist_free_all,             :curl_slist_free_all,      [:pointer],                     :void
         base.instance_variable_set(:@blocking, true)
